/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import java.awt.*;
import java.awt.event.*;
import java.text.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;
import java.awt.GridBagLayout;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;


public class ApplicationDemoFrame extends HFrame {
	// App Prefs
	private static final ApplicationPreferences appPrefs = new ApplicationPreferences("JavaGPE");
	
	//components
	private final HTextField textfield = new HTextField("Test");
	private final HTextArea textarea = new HTextArea();
	private final HEditorPane editorpane = new HEditorPane();
	private final HComboBox combobox = new HComboBox();
	private final JButton button = new JButton("enable / disable editing");
	private final HEditableList editlist = new HEditableList();
	
	
	public ApplicationDemoFrame()  {
		super("JavaGPE: Demo");
		
		// properties
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		combobox.setEditable(true);
		
		// listener
		button.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { 
			textfield.setEditable(! textfield.isEditable()); 
			textarea.setEditable(! textarea.isEditable());
			editorpane.setEditable(! editorpane.isEditable()); 
			combobox.setEditable(! combobox.isEditable());
		}});
		
		// create and set panel
		setContentPane(createPanel());
		
		// add menus
		setJMenuBar(createJMenuBar());
		
		// set bounds
		setBounds(100,100,800,600);
		
		// add prefs
		appPrefs.add("ApplicationDemoFrame", this);
		appPrefs.add("ApplicationDemoFrame.TextField", textfield);
		appPrefs.add("ApplicationDemoFrame.TextArea", textarea);
		appPrefs.add("ApplicationDemoFrame.EditorPane", editorpane);
	}

	
	private JMenuBar createJMenuBar()  {
		// variables
		JMenu menu = null;
		JMenuItem item = null;
		
		// menu bar
		final HMenuBar menubar = new HMenuBar();
		
		// menu: file
		menu = new JMenu("File");
		menubar.add(menu);
		
		// item: file
		item = new JMenuItem("New");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("New"); }});
		item.setIcon(HIconFactory.getMenuIcon("filenew"));
		item.setAccelerator(KeyStroke.getKeyStroke("control N"));
		menu.add(item);
		
		// item: open
		item = new JMenuItem("Open");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Open"); }});
		item.setIcon(HIconFactory.getMenuIcon("fileopen"));
		item.setAccelerator(KeyStroke.getKeyStroke("control O"));
		menu.add(item);
		
		// item: close
		item = new JMenuItem("Close");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Close"); }});
		item.setIcon(HIconFactory.getMenuIcon("fileclose"));
		item.setAccelerator(KeyStroke.getKeyStroke("control W"));
		menu.add(item);
		
		// item: quit
		item = new JMenuItem("Quit");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { exit(0); }});
		item.setIcon(HIconFactory.getMenuIcon("exit"));
		item.setAccelerator(KeyStroke.getKeyStroke("control Q"));
		menu.addSeparator();
		menu.add(item);
		
		// menu: edit
		menu = new JMenu("Edit");
		menubar.add(menu);
		
		// item: cut
		item = new JMenuItem("Cut");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Cut"); }});
		item.setIcon(HIconFactory.getMenuIcon("editcut"));
		item.setAccelerator(KeyStroke.getKeyStroke("control X"));
		menu.add(item);
		
		// item: copy
		item = new JMenuItem("Copy");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Copy"); }});
		item.setIcon(HIconFactory.getMenuIcon("editcopy"));
		item.setAccelerator(KeyStroke.getKeyStroke("control C"));
		menu.add(item);
		
		// item: paste
		item = new JMenuItem("Paste");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Paste"); }});
		item.setIcon(HIconFactory.getMenuIcon("editpaste"));
		item.setAccelerator(KeyStroke.getKeyStroke("control V"));
		menu.add(item);
		
		// menu: help
		menu = new JMenu("Help");
		menubar.setHelpMenu(menu);
		
		// item: help
		item = new JMenuItem("Help");
		item.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { System.out.println("Help"); }});
		item.setIcon(HIconFactory.getMenuIcon("help"));
		menu.add(item);
		
		// return result
		return menubar;
	}

	
	private JPanel createPanel()  {
		// create panel
		final JPanel panel = new JPanel();
		panel.setBorder(UIPreferences.getFrameBorder());
		panel.setLayout(new GridBagLayout());
		
		// create constraints
		final GridBagConstraints c = UIPreferences.getGridBagConstraints();
		
		// add components
		c.gridx = 0; c.gridy=0; c.gridwidth=1; c.gridheight=1; c.weightx=1; c.weighty=1; c.fill = GridBagConstraints.BOTH;
		panel.add(new JScrollPane(textarea), c);
		c.gridx = 1; c.gridy=0; c.gridwidth=1; c.gridheight=1; c.weightx=1; c.weighty=1; c.fill = GridBagConstraints.BOTH;
		panel.add(new JScrollPane(editorpane), c);
		c.gridx = 0; c.gridy=1; c.gridwidth=2; c.gridheight=1; c.weightx=1; c.weighty=0; c.fill = GridBagConstraints.HORIZONTAL;
		panel.add(textfield, c);
		c.gridx = 0; c.gridy=2; c.gridwidth=2; c.gridheight=1; c.weightx=1; c.weighty=0; c.fill = GridBagConstraints.HORIZONTAL;
		panel.add(combobox, c);
		c.gridx = 0; c.gridy=3; c.gridwidth=2; c.gridheight=1; c.weightx=1; c.weighty=0; c.fill = GridBagConstraints.HORIZONTAL;
		panel.add(button, c);
		c.gridx = 0; c.gridy=4; c.gridwidth=2; c.gridheight=1; c.weightx=1; c.weighty=1; c.fill = GridBagConstraints.BOTH;
		panel.add(editlist, c);
		
		// return panel
		return panel;
	}

	
	public static void exit(int value)  {
		appPrefs.save();
		System.exit(value);
	}

	
	public static void main(String [] args)  {
		// init UI preferences
		UIPreferences.init();
		
		// create and open the frame
		final ApplicationDemoFrame test = new ApplicationDemoFrame();
		test.addWindowListener(new WindowAdapter() { public void windowClosing(WindowEvent e) { exit(0); }});
		test.setVisible(true);
		
		// test error feedback
		UIManager.getLookAndFeel().provideErrorFeedback(test);
	}

}
