/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.hillenbrand.demo;

import de.hillenbrand.jreqtools.*;
import de.hillenbrand.swing.*;
import de.hillenbrand.system.*;
import java.util.*;
import de.hillenbrand.swing.renderer.*;


public class SelectRequesterDemo {
	
	
	private final static class TestData {
		// Property: id
		protected int id;
		// Property: name
		protected String name;
		
		public TestData(int id, String name)  {
			this.id = id;
			this.name = name;
		}

		/**
		* Returns the value of the id property.
		*/

		
		public int getId()  {
			return id;
		}

		/**
		* Returns the value of the name property.
		*/

		
		public String getName()  {
			return name;
		}

		/**
		* Assigns the value of the id property.
		*/

		
		public void setId(int arg)  {
			id = arg;
		}

		/**
		* Assigns the value of the name property.
		*/

		
		public void setName(String arg)  {
			name = arg;
		}

		
		public String toString()  {
			return id + " (" + name+")";
		}

	}

	
	private final static class TestDataCellRenderer extends MultiLineListCellRenderer {
		
		
		public TestDataCellRenderer()  {
			super(HIconFactory.getMenuIcon("attach"), new String [] { "ID:"} );
		}

		
		public String getTitle(Object value)  {
			return ((TestData)value).name;
		}

		
		public String getValue(int index, Object value)  {
			return ""+((TestData)value).id;
		}

	}

	/**
	* Shows how a SelectRequester might be put into operation using MultiSelection and a Comparator.
	*/

	
	public static void main(String [] args)  {
		// init the UI System
		UIPreferences.init();
		
		// data
		final TestData [] data = {
			new TestData(1, "Peter"),
			new TestData(2, "Mary"),
			new TestData(3, "James"),
			new TestData(4, "Steven"),
			new TestData(5, "Rachel"),
		};
		
		final TestData [] select = {
			new TestData(1, "Peter"),
			new TestData(4, "Steven"),
			new TestData(5, "Rachel"),
		};
		
		final Comparator comparator = new Comparator() {
			public int compare(Object o1, Object o2) {
				return ((TestData)o2).id - ((TestData)o1).id;
		}};
		
		final SelectRequester sr = new SelectRequester("Title", "Message:", data, select);
		sr.setListCellRenderer(new TestDataCellRenderer());
		sr.setComparator(comparator);
		if (sr.request((HFrame)null) == SelectRequester.OK)
			{
			System.out.println("Selection:");
			final Object [] selected = sr.getSelectedValues();
			for (int i=0; i<selected.length; ++i) System.out.println("-> " + selected[i]);
			}
		else System.out.println("Selection canceled.");
		
		System.exit(0);
	}

}
